@@ -9,7 +9,7 @@ import src
 from src.entities.invoice import Invoice
 from src.entities.order import Queue, Order
 from src.entities.price import Price
-from src.entities.response import CatalogoResponse, PriceResponse, InvoiceResponse
+from src.entities.response import CatalogoResponse, PriceResponse, InvoiceResponse, TrackingResponse
 from src.entities.tracking import Tracking
 
 logger = logging.getLogger()
@@ -195,7 +195,7 @@ def post_invoices(url: str, invoice: Invoice, token) -> Optional[InvoiceResponse
         return InvoiceResponse(3, str(ex))
 
 
-def post_tracking(url: str, tracking: Tracking, token) -> Optional[InvoiceResponse]:
+def post_tracking(url: str, tracking: Tracking, token) -> Optional[TrackingResponse]:
     """
     Enviar rastreio de um pedido para api okvendas
     Args:
