@@ -78,9 +78,9 @@ def get_query_client(connection_type: str):
 
 def get_query_order(connection_type: str):
 	if connection_type.lower() == 'mysql':
-		return 'select id from openk_semaforo.pedido where pedido_id = %s'
+		return 'select id from openk_semaforo.pedido where pedido_id = %s and data_sincronizacao is null'
 	elif connection_type.lower() == 'oracle':
-		return 'SELECT ID FROM OPENK_SEMAFORO.PEDIDO WHERE PEDIDO_ID = :order_id'
+		return 'SELECT ID FROM OPENK_SEMAFORO.PEDIDO WHERE PEDIDO_ID = :order_id AND DATA_SINCRONIZACAO IS NULL'
 	elif connection_type.lower() == 'sqlserver':
 		return ''
 
