@@ -38,8 +38,7 @@ class Order:
             self.parcels = payments[0].parcels
             self.payment_type = payments[0].type
 
-        print(f'\n\n {forma_envio_parceiro} \n\n')
-        partner_shipping_methods: list[PartnerShippingMethod] = [PartnerShippingMethod(**f) for f in forma_envio_parceiro]
+        partner_shipping_methods: list[PartnerShippingMethod] = [PartnerShippingMethod(**forma_envio_parceiro)]
         if len(partner_shipping_methods) > 0:
             self.shipping_mode = partner_shipping_methods[0].shipping_mode
 
@@ -88,7 +87,7 @@ class Address:
         self.city: str = cidade
         self.state: str = estado
         self.reference: str = referencia
-        self.address_type: str = tipo_logradouro
+        self.address_type: str = tipo_logradouro or 'Rua'
 
 
 class OrderItem:
